@@ -35,7 +35,7 @@ class Operation:
         """
         params = Dict(kwargs)
         xmin, ymin, xmax, ymax = [int(item) for item in params.finalBox]
-        detectedObject = params.copyImage[ymin:ymax, xmin:xmax] # if detectedObject dont want color open this
+        detectedObject = params.copyImage[ymin:ymax, xmin:xmax]  # if detectedObject dont want color open this
         if len(params.mask_boundary):
             cv2.polylines(params.image, [params.mask_boundary], True, (0, 255, 0), 3)
             # TODO mask deprecated
@@ -60,7 +60,10 @@ class Operation:
 
         imageNumber = os.path.basename(params.writePaths[1]).split(".")[0]
         imageSaveType = os.path.basename(params.writePaths[1]).split(".")[1]
-        saveName = imageNumber + "_{}.".format(Generator.unique_matchId_generator()) + imageSaveType
+        saveName = imageNumber + "_{}.".format(Generator.unique_matchId_generator()) + imageSaveType + '.jpeg'
+
+        # if not saveName in ['jpg', 'jpeg']:
+        #     saveName = saveName + '.jpeg'
         detectedObjectPath = os.path.join("Exports", params.file_id, "ObjectsImage", saveName)
         cv2.imwrite(detectedObjectPath, detectedObject)
 
@@ -77,7 +80,7 @@ class Operation:
         return cv2.imread(detectedObjectPath, 0)
 
     @staticmethod
-    def binary_mask_to_polygon(binary_mask: np.ndarray, tolerance: int=0) -> np.ndarray:
+    def binary_mask_to_polygon(binary_mask: np.ndarray, tolerance: int = 0) -> np.ndarray:
         def close_contour(contour: np.ndarray) -> np.ndarray:
             if not np.array_equal(contour[0], contour[-1]):
                 contour = np.vstack((contour, contour[0]))
@@ -100,4 +103,3 @@ class Operation:
             polygons.append(segmentation)
 
         return polygons
-
