@@ -33,7 +33,8 @@ class PreProcessor:
             print("Image already exist!")
         else:
             image = Convertor.url_to_image(params.path)
-            cv2.imwrite(os.path.join('Exports', params.file_id, 'imgs', image_name), image)
+            if params.imageWrite:
+                cv2.imwrite(os.path.join('Exports', params.file_id, 'imgs', image_name), image)
 
         width = image.shape[1]
         height = image.shape[0]
@@ -47,7 +48,7 @@ class PreProcessor:
             # TODO it will be dynamic operation
             numrows = round(width / params.cfg.image.mobileTile)
             numcols = round(height / params.cfg.image.mobileTile)
-            if not (numcols >=1 and numcols >=1):
+            if not (numcols >= 1 and numcols >= 1):
                 assert "Check your mobileTile parameter"
             cropImage = image.copy()
             return image, height, width, cropImage, params.path, params.cfg, numrows, numcols
@@ -77,4 +78,58 @@ class PreProcessor:
                 medblurimg = cv2.medianBlur(image, ccfg.image_preprocess.medianblur.ksize, )
                 return medblurimg
             else:
-                return image
\ No newline at end of file
+                return image
+
+    @staticmethod
+    def resize(input_imgs: list) -> list:
+        """
+
+        Args:
+            ingput_imgs: np.ndarray imgs in input_imgs
+
+        Returns:
+
+        """
+        output_imgs = []
+        for img in input_imgs:
+            img = cv2.resize(img, (400, 200))
+            output_imgs.append(img)
+        return output_imgs
+
+    @staticmethod
+    def clahe(input_imgs: list) -> list:
+        '''
+        Adaptive Histogram Equalization
+        :input_imgs: np.ndarray imgs in input_imgs
+        :return: bgr-image
+        '''
+        output_imgs = []
+        for img in input_imgs:
+            hsv_img = cv2.cvtColor(img, cv2.COLOR_BGR2HSV)
+            h, s, v, = hsv_img[:, :, 0], hsv_img[:, :, 1], hsv_img[:, :, 2]
+            clahe = cv2.createCLAHE(clipLimit=2.0, tileGridSize=(16, 16))
+            v = clahe.apply(v)
+            hsv_img = np.dstack((h, s, v))
+            bgr = cv2.cvtColor(hsv_img, cv2.COLOR_HSV2BGR)
+            output_imgs.append(bgr)
+        return output_imgs
+
+
+class Orb:
+    orb = cv2.ORB_create(10000)
+    orb.setFastThreshold(0)
+    if cv2.__version__.startswith('3'):
+        matcher = cv2.BFMatcher(cv2.NORM_HAMMING)
+    else:
+        matcher = cv2.BFMatcher_create(cv2.NORM_HAMMING)
+
+
+class Size:
+    def __init__(self, width, height):
+        '''
+        Class for the width,height parameters
+        :param width:
+        :param height:
+        '''
+        self.width = width
+        self.height = height
